astro\_ghost package
====================

Submodules
----------

astro\_ghost.DLR module
-----------------------

.. automodule:: astro_ghost.DLR
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.NEDQueryFunctions module
-------------------------------------

.. automodule:: astro_ghost.NEDQueryFunctions
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.PS1QueryFunctions module
-------------------------------------

.. automodule:: astro_ghost.PS1QueryFunctions
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.SimbadQueryFunctions module
----------------------------------------

.. automodule:: astro_ghost.SimbadQueryFunctions
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.TNSQueryFunctions module
-------------------------------------

.. automodule:: astro_ghost.TNSQueryFunctions
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.conftest module
----------------------------

.. automodule:: astro_ghost.conftest
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.ghostHelperFunctions module
----------------------------------------

.. automodule:: astro_ghost.ghostHelperFunctions
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.gradientAscent module
----------------------------------

.. automodule:: astro_ghost.gradientAscent
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.hostMatching module
--------------------------------

.. automodule:: astro_ghost.hostMatching
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.photoz\_helper module
----------------------------------

.. automodule:: astro_ghost.photoz_helper
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.sourceCleaning module
----------------------------------

.. automodule:: astro_ghost.sourceCleaning
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.starSeparation module
----------------------------------

.. automodule:: astro_ghost.starSeparation
   :members:
   :undoc-members:
   :show-inheritance:

astro\_ghost.stellarLocus module
--------------------------------

.. automodule:: astro_ghost.stellarLocus
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: astro_ghost
   :members:
   :undoc-members:
   :show-inheritance:
